summaryrefslogtreecommitdiffstats
path: root/kio/kio/global.h
diff options
context:
space:
mode:
Diffstat (limited to 'kio/kio/global.h')
-rw-r--r--kio/kio/global.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/kio/kio/global.h b/kio/kio/global.h
index fc18f1953..402d7b431 100644
--- a/kio/kio/global.h
+++ b/kio/kio/global.h
@@ -420,12 +420,12 @@ namespace KIO
/**
* Returns the mount point on which resides @p filename.
* For instance if /home is a separate partition, tqfindPathMountPoint("/home/user/blah")
* will return /home
* @param filename the file name to check
* @return the mount point of the given @p filename
*/
- KIO_EXPORT TQString tqfindPathMountPoint( const TQString & filename );
+ KIO_EXPORT TQString findPathMountPoint( const TQString & filename );
/**
* Checks if the path belongs to a filesystem that is probably
@@ -475,12 +475,12 @@ namespace KIO
*
* Any file or URL can be represented by the UDSEntry type below
* A UDSEntry is a list of atoms
- * Each atom tqcontains a specific bit of information for the file
+ * Each atom contains a specific bit of information for the file
*
* The following UDS constants represent the different possible values
* for m_uds in the UDS atom structure below
*
- * Each atom tqcontains a specific bit of information for the file
+ * Each atom contains a specific bit of information for the file
*/
class KIO_EXPORT UDSAtom
{
@@ -536,7 +536,7 @@ public:
it != metaData.end();
++it)
{
- tqreplace(it.key(), it.data());
+ replace(it.key(), it.data());
}
return *this;
}
@@ -420,12 +420,12 @@ namespace KIO
/**
* Returns the mount point on which resides @p filename.
- * For instance if /home is a separate partition, tqfindPathMountPoint("/home/user/blah")
+ * For instance if /home is a separate partition, findPathMountPoint("/home/user/blah")
* will return /home
* @param filename the file name to check